@@ -38,6 +38,7 @@
 #include "linux/input.h"
 
 #include "libinput.h"
+#include "libinput-private-config.h"
 #include "libinput-util.h"
 #include "libinput-version.h"
 
@@ -76,6 +77,11 @@ struct wheel_angle {
 	double x, y;
 };
 
+/* A pair of wheel click data for the 120-normalized range */
+struct wheel_v120 {
+	int x, y;
+};
+
 /* A pair of angles in degrees */
 struct tilt_degrees {
 	double x, y;
@@ -307,6 +313,13 @@ struct libinput_device_config_rotation {
 	unsigned int (*get_default_angle)(struct libinput_device *device);
 };
 
+struct libinput_device_config_gesture {
+	enum libinput_config_status (*set_hold_enabled)(struct libinput_device *device,
+			 enum libinput_config_hold_state enabled);
+	enum libinput_config_hold_state (*get_hold_enabled)(struct libinput_device *device);
+	enum libinput_config_hold_state (*get_hold_default)(struct libinput_device *device);
+};
+
 struct libinput_device_config {
 	struct libinput_device_config_tap *tap;
 	struct libinput_device_config_calibration *calibration;
@@ -319,6 +332,7 @@ struct libinput_device_config {
 	struct libinput_device_config_middle_emulation *middle_emulation;
 	struct libinput_device_config_dwt *dwt;
 	struct libinput_device_config_rotation *rotation;
+	struct libinput_device_config_gesture *gesture;
 };
 
 struct libinput_device_group {
@@ -559,12 +573,29 @@ pointer_notify_button(struct libinput_device *device,
 		      enum libinput_button_state state);
 
 void
-pointer_notify_axis(struct libinput_device *device,
-		    uint64_t time,
-		    uint32_t axes,
-		    enum libinput_pointer_axis_source source,
-		    const struct normalized_coords *delta,
-		    const struct discrete_coords *discrete);
+pointer_notify_axis_finger(struct libinput_device *device,
+			   uint64_t time,
+			   uint32_t axes,
+			   const struct normalized_coords *delta);
+void
+pointer_notify_axis_continuous(struct libinput_device *device,
+			       uint64_t time,
+			       uint32_t axes,
+			       const struct normalized_coords *delta);
+
+void
+pointer_notify_axis_legacy_wheel(struct libinput_device *device,
+				 uint64_t time,
+				 uint32_t axes,
+				 const struct normalized_coords *delta,
+				 const struct discrete_coords *discrete);
+
+void
+pointer_notify_axis_wheel(struct libinput_device *device,
+			  uint64_t time,
+			  uint32_t axes,
+			  const struct normalized_coords *delta,
+			  const struct wheel_v120 *v120);
 
 void
 touch_notify_touch_down(struct libinput_device *device,
@@ -627,6 +658,17 @@ gesture_notify_pinch_end(struct libinput_device *device,
 			 double scale,
 			 bool cancelled);
 
+void
+gesture_notify_hold(struct libinput_device *device,
+		    uint64_t time,
+		    int finger_count);
+
+void
+gesture_notify_hold_end(struct libinput_device *device,
+			uint64_t time,
+			int finger_count,
+			bool cancelled);
+
 void
 tablet_notify_axis(struct libinput_device *device,
 		   uint64_t time,
