@@ -37,6 +37,7 @@
 
 #include "check-double-macros.h"
 
+#include "libinput-private-config.h"
 #include "libinput-util.h"
 #include "quirks.h"
 
@@ -319,7 +320,6 @@ enum litest_device_type {
 	LITEST_KEYBOARD_QUIRKED,
 	LITEST_SYNAPTICS_PRESSUREPAD,
 	LITEST_GENERIC_PRESSUREPAD,
-	LITEST_MOUSE_FORMAT_STRING,
 };
 
 #define LITEST_DEVICELESS	-2
@@ -747,9 +747,13 @@ litest_is_button_event(struct libinput_event *event,
 
 struct libinput_event_pointer *
 litest_is_axis_event(struct libinput_event *event,
+		     enum libinput_event_type axis_type,
 		     enum libinput_pointer_axis axis,
 		     enum libinput_pointer_axis_source source);
 
+bool
+litest_is_high_res_axis_event(struct libinput_event *event);
+
 struct libinput_event_pointer *
 litest_is_motion_event(struct libinput_event *event);
 
@@ -797,6 +801,13 @@ struct libinput_event_tablet_tool *
 litest_is_proximity_event(struct libinput_event *event,
 			  enum libinput_tablet_tool_proximity_state state);
 
+double
+litest_event_pointer_get_value(struct libinput_event_pointer *ptrev,
+			       enum libinput_pointer_axis axis);
+
+enum libinput_pointer_axis_source
+litest_event_pointer_get_axis_source(struct libinput_event_pointer *event);
+
 void
 litest_assert_key_event(struct libinput *li, unsigned int key,
 			enum libinput_key_state state);
@@ -808,13 +819,24 @@ litest_assert_button_event(struct libinput *li,
 
 void
 litest_assert_scroll(struct libinput *li,
+		     enum libinput_event_type axis_type,
 		     enum libinput_pointer_axis axis,
 		     int minimum_movement);
 
+void
+litest_assert_axis_end_sequence(struct libinput *li,
+				enum libinput_event_type axis_type,
+				enum libinput_pointer_axis axis,
+				enum libinput_pointer_axis_source source);
+
 void
 litest_assert_only_typed_events(struct libinput *li,
 				enum libinput_event_type type);
 
+void
+litest_assert_only_axis_events(struct libinput *li,
+			       enum libinput_event_type axis_type);
+
 void
 litest_assert_no_typed_events(struct libinput *li,
 			      enum libinput_event_type type);
@@ -893,6 +915,12 @@ litest_timeout_gesture(void);
 void
 litest_timeout_gesture_scroll(void);
 
+void
+litest_timeout_gesture_hold(void);
+
+void
+litest_timeout_gesture_quick_hold(void);
+
 void
 litest_timeout_trackpoint(void);
 
@@ -1163,6 +1191,30 @@ litest_sendevents_ext_mouse(struct litest_device *dev)
 	litest_assert_int_eq(status, expected);
 }
 
+static inline void
+litest_enable_hold_gestures(struct libinput_device *device)
+{
+	enum libinput_config_status status, expected;
+
+	expected = LIBINPUT_CONFIG_STATUS_SUCCESS;
+	status = libinput_device_config_gesture_set_hold_enabled(device,
+								 LIBINPUT_CONFIG_HOLD_ENABLED);
+
+	litest_assert_int_eq(status, expected);
+}
+
+static inline void
+litest_disable_hold_gestures(struct libinput_device *device)
+{
+	enum libinput_config_status status, expected;
+
+	expected = LIBINPUT_CONFIG_STATUS_SUCCESS;
+	status = libinput_device_config_gesture_set_hold_enabled(device,
+								 LIBINPUT_CONFIG_HOLD_DISABLED);
+
+	litest_assert_int_eq(status, expected);
+}
+
 static inline bool
 litest_touchpad_is_external(struct litest_device *dev)
 {
