@@ -261,12 +261,12 @@ END_TEST
 
 TEST_COLLECTION(trackball)
 {
-	litest_add("trackball:rotation", trackball_rotation_config_defaults, LITEST_TRACKBALL, LITEST_ANY);
-	litest_add("trackball:rotation", trackball_rotation_config_invalid_range, LITEST_TRACKBALL, LITEST_ANY);
-	litest_add("trackball:rotation", trackball_rotation_config_no_rotation, LITEST_ANY, LITEST_TRACKBALL);
-	litest_add("trackball:rotation", trackball_rotation_config_right_angle, LITEST_TRACKBALL, LITEST_ANY);
-	litest_add("trackball:rotation", trackball_rotation_config_odd_angle, LITEST_TRACKBALL, LITEST_ANY);
-	litest_add("trackball:rotation", trackball_rotation_x, LITEST_TRACKBALL, LITEST_ANY);
-	litest_add("trackball:rotation", trackball_rotation_y, LITEST_TRACKBALL, LITEST_ANY);
-	litest_add("trackball:rotation", trackball_rotation_accel, LITEST_TRACKBALL, LITEST_ANY);
+	litest_add(trackball_rotation_config_defaults, LITEST_TRACKBALL, LITEST_ANY);
+	litest_add(trackball_rotation_config_invalid_range, LITEST_TRACKBALL, LITEST_ANY);
+	litest_add(trackball_rotation_config_no_rotation, LITEST_ANY, LITEST_TRACKBALL);
+	litest_add(trackball_rotation_config_right_angle, LITEST_TRACKBALL, LITEST_ANY);
+	litest_add(trackball_rotation_config_odd_angle, LITEST_TRACKBALL, LITEST_ANY);
+	litest_add(trackball_rotation_x, LITEST_TRACKBALL, LITEST_ANY);
+	litest_add(trackball_rotation_y, LITEST_TRACKBALL, LITEST_ANY);
+	litest_add(trackball_rotation_accel, LITEST_TRACKBALL, LITEST_ANY);
 }
