@@ -77,13 +77,25 @@ START_TEST(trackpoint_scroll)
 	litest_drain_events(li);
 
 	litest_button_scroll(dev, BTN_MIDDLE, 1, 6);
-	litest_assert_scroll(li, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL, 6);
+	litest_assert_scroll(li,
+			     LIBINPUT_EVENT_POINTER_SCROLL_CONTINUOUS,
+			     LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL,
+			     6);
 	litest_button_scroll(dev, BTN_MIDDLE, 1, -7);
-	litest_assert_scroll(li, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL, -7);
+	litest_assert_scroll(li,
+			     LIBINPUT_EVENT_POINTER_SCROLL_CONTINUOUS,
+			     LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL,
+			     -7);
 	litest_button_scroll(dev, BTN_MIDDLE, 8, 1);
-	litest_assert_scroll(li, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL, 8);
+	litest_assert_scroll(li,
+			     LIBINPUT_EVENT_POINTER_SCROLL_CONTINUOUS,
+			     LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL,
+			     8);
 	litest_button_scroll(dev, BTN_MIDDLE, -9, 1);
-	litest_assert_scroll(li, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL, -9);
+	litest_assert_scroll(li,
+			     LIBINPUT_EVENT_POINTER_SCROLL_CONTINUOUS,
+			     LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL,
+			     -9);
 
 	/* scroll smaller than the threshold should not generate axis events */
 	litest_button_scroll(dev, BTN_MIDDLE, 1, 1);
@@ -147,7 +159,7 @@ START_TEST(trackpoint_scroll_source)
 	while ((event = libinput_get_event(li))) {
 		ptrev = libinput_event_get_pointer_event(event);
 
-		ck_assert_int_eq(libinput_event_pointer_get_axis_source(ptrev),
+		ck_assert_int_eq(litest_event_pointer_get_axis_source(ptrev),
 				 LIBINPUT_POINTER_AXIS_SOURCE_CONTINUOUS);
 
 		libinput_event_destroy(event);
@@ -164,6 +176,8 @@ START_TEST(trackpoint_topsoftbuttons_left_handed_trackpoint)
 	struct libinput_event *event;
 	struct libinput_device *device;
 
+	litest_disable_hold_gestures(touchpad->libinput_device);
+
 	trackpoint = litest_add_device(li, LITEST_TRACKPOINT);
 	litest_drain_events(li);
 	/* touchpad right-handed, trackpoint left-handed */
@@ -207,6 +221,8 @@ START_TEST(trackpoint_topsoftbuttons_left_handed_touchpad)
 	struct libinput_event *event;
 	struct libinput_device *device;
 
+	litest_disable_hold_gestures(touchpad->libinput_device);
+
 	trackpoint = litest_add_device(li, LITEST_TRACKPOINT);
 	litest_drain_events(li);
 	/* touchpad left-handed, trackpoint right-handed */
@@ -248,6 +264,8 @@ START_TEST(trackpoint_topsoftbuttons_left_handed_both)
 	struct libinput_event *event;
 	struct libinput_device *device;
 
+	litest_disable_hold_gestures(touchpad->libinput_device);
+
 	trackpoint = litest_add_device(li, LITEST_TRACKPOINT);
 	litest_drain_events(li);
 	/* touchpad left-handed, trackpoint left-handed */
@@ -293,6 +311,7 @@ START_TEST(trackpoint_palmdetect)
 	int i;
 
 	touchpad = litest_add_device(li, LITEST_SYNAPTICS_I2C);
+	litest_disable_hold_gestures(touchpad->libinput_device);
 	litest_drain_events(li);
 
 	for (i = 0; i < 10; i++) {
@@ -328,6 +347,7 @@ START_TEST(trackpoint_palmdetect_resume_touch)
 	int i;
 
 	touchpad = litest_add_device(li, LITEST_SYNAPTICS_I2C);
+	litest_disable_hold_gestures(touchpad->libinput_device);
 	litest_drain_events(li);
 
 	for (i = 0; i < 10; i++) {
@@ -361,6 +381,7 @@ START_TEST(trackpoint_palmdetect_require_min_events)
 	struct libinput *li = trackpoint->libinput;
 
 	touchpad = litest_add_device(li, LITEST_SYNAPTICS_I2C);
+	litest_disable_hold_gestures(touchpad->libinput_device);
 	litest_drain_events(li);
 
 	/* A single event does not trigger palm detection */
@@ -386,6 +407,7 @@ START_TEST(trackpoint_palmdetect_require_min_events_timeout)
 	struct libinput *li = trackpoint->libinput;
 
 	touchpad = litest_add_device(li, LITEST_SYNAPTICS_I2C);
+	litest_disable_hold_gestures(touchpad->libinput_device);
 	litest_drain_events(li);
 
 	for (int i = 0; i < 10; i++) {
